aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorcash <cash.costello@gmail.com>2012-01-04 21:31:53 -0500
committercash <cash.costello@gmail.com>2012-01-04 21:31:53 -0500
commit1bd4a6e422e17043b6fd05b1dfcc7f6f71bd2fcc (patch)
tree550f444ce3a0c2f97c4a9bf451c0eadaeeb2f084
parent29f54cb2cfbc0edac0bd11fb325baf375a8b7e15 (diff)
downloadelgg-1bd4a6e422e17043b6fd05b1dfcc7f6f71bd2fcc.tar.gz
elgg-1bd4a6e422e17043b6fd05b1dfcc7f6f71bd2fcc.tar.bz2
updated options on navigation/tabs
-rw-r--r--mod/embed/views/default/navigation/menu/embed.php2
-rw-r--r--views/default/navigation/tabs.php24
2 files changed, 13 insertions, 13 deletions
diff --git a/mod/embed/views/default/navigation/menu/embed.php b/mod/embed/views/default/navigation/menu/embed.php
index 1a6a18f05..bca673f59 100644
--- a/mod/embed/views/default/navigation/menu/embed.php
+++ b/mod/embed/views/default/navigation/menu/embed.php
@@ -10,7 +10,7 @@ foreach ($vars['menu']['default'] as $menu_item) {
$tabs[] = array(
'title' => $menu_item->getText(),
'url' => 'embed/tab/' . $menu_item->getName(),
- 'url_class' => 'embed-section',
+ 'link_class' => 'embed-section',
'selected' => $menu_item->getSelected(),
);
}
diff --git a/views/default/navigation/tabs.php b/views/default/navigation/tabs.php
index 6159fbfa5..95e3f2669 100644
--- a/views/default/navigation/tabs.php
+++ b/views/default/navigation/tabs.php
@@ -5,13 +5,13 @@
* @uses string $vars['type'] horizontal || vertical - Defaults to horizontal
* @uses string $vars['class'] Additional class to add to ul
* @uses array $vars['tabs'] A multi-dimensional array of tab entries in the format array(
- * 'text' => string, // The string between the <a></a> tags. If not set, 'title' parameter will be used instead
+ * 'text' => string, // The string between the <a></a> tags
* 'href' => string, // URL for the link
* 'class' => string // Class of the li element
* 'id' => string, // ID of the li element
* 'selected' => bool // if this li element is currently selected
* 'url_class' => string, // Class to pass to the link
* 'url_id' => string, // ID to pass to the link
* )
*/
$options = elgg_clean_vars($vars);
@@ -30,11 +30,11 @@ if (isset($vars['class'])) {
unset($options['tabs']);
unset($options['type']);
-$options = elgg_format_attributes($options);
+$attributes = elgg_format_attributes($options);
if (isset($vars['tabs']) && is_array($vars['tabs']) && !empty($vars['tabs'])) {
?>
- <ul <?php echo $options ?>>
+ <ul <?php echo $attributes; ?>>
<?php
foreach ($vars['tabs'] as $info) {
$class = elgg_extract('class', $info, '');
@@ -61,14 +61,14 @@ if (isset($vars['tabs']) && is_array($vars['tabs']) && !empty($vars['tabs'])) {
$options['text'] = $options['title'];
unset($options['title']);
}
- if (isset($info['url_class'])) {
- $options['class'] = $options['url_class'];
- unset($options['url_class']);
+ if (isset($info['link_class'])) {
+ $options['class'] = $options['link_class'];
+ unset($options['link_class']);
}
- if (isset($info['url_id'])) {
- $options['id'] = $options['url_id'];
- unset($options['url_id']);
+ if (isset($info['link_id'])) {
+ $options['id'] = $options['link_id'];
+ unset($options['link_id']);
}
$link = elgg_view('output/url', $options);
@@ -5,13 +5,13 @@
* 'class' => string // Class of the li element
* 'id' => string, // ID of the li element
- * 'selected' => bool // if this li element is currently selected
- * 'url_class' => string, // Class to pass to the link
- * 'url_id' => string, // ID to pass to the link
+ * 'selected' => bool // if this tab is currently selected (applied to li element)
+ * 'link_class' => string, // Class to pass to the link
+ * 'link_id' => string, // ID to pass to the link
* )
*/